package examples;

import java.net.URL;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;

import gate.*;
import gate.creole.SerialAnalyserController;
import gate.util.OffsetComparator;


public class NamedEntities {
	
	
	public static void main(String args[]) {
		// initialise GATE
		try {
			
			Gate.init();
			
			// create a GATE document from an URL 
			Document doc=Factory.newDocument(
					new URL("file:///C:/horacio/ESSLLI-2007/resources/texts/19970814_001.bis.xml"));
			// create a Corpus 
			Corpus corpus=Factory.newCorpus("a corpus");
			// put document in the corpus
			corpus.add(doc);		
			// create a GATE tokeniser
			ProcessingResource tokeniser=(ProcessingResource)
			Factory.createResource("gate.creole.tokeniser.DefaultTokeniser");
			// create a GATE sentence splitter
			ProcessingResource splitter=(ProcessingResource)
			Factory.createResource("gate.creole.splitter.SentenceSplitter");
			// create a POS tagger
			ProcessingResource tagger=(ProcessingResource)
			Factory.createResource("gate.creole.POSTagger");
			// create a gazetteer list lookup
			ProcessingResource gazetteer=(ProcessingResource)
			Factory.createResource("gate.creole.gazetteer.DefaultGazetteer");
			// create a jape transducer
			ProcessingResource nes=(ProcessingResource)
			Factory.createResource("gate.creole.ANNIETransducer");
			// create a GATE controller to hold the tokeniser
			SerialAnalyserController controller=(SerialAnalyserController) 
			Factory.createResource("gate.creole.SerialAnalyserController");
			// add tokeniser as first 
			controller.add(tokeniser);
			// add sentence splitter
			controller.add(splitter);
			// add pos tagger
			controller.add(tagger);
			// add gazetteer
			controller.add(gazetteer);
			// add recogniser
			controller.add(nes);
			
			// set the corpus
			controller.setCorpus(corpus);
			// run the controller
			controller.execute();
			// see what is in the document
//			 process one token at a time
			// get the default annotation set
			AnnotationSet all=doc.getAnnotations();
			// get the tokens in the default set
			AnnotationSet persons=all.get("Person");
			// put tokens in an array
			ArrayList personList=new ArrayList(persons);
			// create a comparator
			Comparator offsetComp=new OffsetComparator();
			//sort the tokens
			Collections.sort(personList,offsetComp);
			// annotation to hold the person
			Annotation person;
			// start and end of the annotation
			Long start, end;
			// get the document content (the 'text' of the document)
			String dc=doc.getContent().toString();
			// the name of the person
			String pname;
			// iterate over the tokens
			for(int t=0;t<personList.size();t++) {
				person=(Annotation)personList.get(t);
				start=person.getStartNode().getOffset();
				end  =person.getEndNode().getOffset();
				pname=dc.substring(start.intValue(),end.intValue());
				System.out.println(pname);
						
			}
				
		} catch(Exception e) {
			e.printStackTrace();
		}
	}

}
