package examples;

import java.net.URL;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;

import gate.*;
import gate.creole.SerialAnalyserController;
import gate.util.OffsetComparator;


public class POSMorph {
	
	
	public static void main(String args[]) {
		// initialise GATE
		try {
			
			Gate.init();
			// create a GATE document from a string
			Document doc=Factory.newDocument(
					new URL("file:///c:/horacio/ESSLLI-2007/resources/texts/document1.txt"));
			// create a Corpus 
			Corpus corpus=Factory.newCorpus("a corpus");
			// put document in the corpus
			corpus.add(doc);		
			// create a GATE tokeniser
			ProcessingResource tokeniser=(ProcessingResource)
			Factory.createResource("gate.creole.tokeniser.DefaultTokeniser");
			// create a GATE sentence splitter
			ProcessingResource splitter=(ProcessingResource)
			Factory.createResource("gate.creole.splitter.SentenceSplitter");
			// create a POS tagger
			ProcessingResource tagger=(ProcessingResource)
			Factory.createResource("gate.creole.POSTagger");
			
			// tell gate we are going to use morph
			Gate.getCreoleRegister().addDirectory(new URL(
					"file:///c:/gate/plugins/Tools"));
			
			// create a Moph analyser
			ProcessingResource morph=(ProcessingResource)
			Factory.createResource("gate.creole.morph.Morph");
			
			// create a GATE controller to hold the tokeniser
			SerialAnalyserController controller=(SerialAnalyserController) 
			Factory.createResource("gate.creole.SerialAnalyserController");
			// add tokeniser as first 
			controller.add(tokeniser);
			// add sentence splitter
			controller.add(splitter);
			// add pos tagger
			controller.add(tagger);
			// add morphological analyser		
			controller.add(morph);
			
			// set the corpus
			controller.setCorpus(corpus);
			// run the controller
			controller.execute();
			// see what is in the document
            // process one token at a time
			// get the default annotation set
			AnnotationSet all=doc.getAnnotations();
			// get the tokens in the default set
			AnnotationSet tokens=all.get("Token");
			// put tokens in an array
			ArrayList tokenList=new ArrayList(tokens);
			// create a comparator
			Comparator offsetComp=new OffsetComparator();
			//sort the tokens
			Collections.sort(tokenList,offsetComp);
			
			Annotation token;
			FeatureMap fm;
			// iterate over the tokens
			for(int t=0;t<tokenList.size();t++) {
				token=(Annotation)tokenList.get(t);
				fm=token.getFeatures();
				System.out.println(fm.get("string")+"/"+fm.get("kind")+"/"+
						fm.get("category")+"/"+fm.get("root"));
				
				
			}
			
			
			

			
			
		} catch(Exception e) {
			e.printStackTrace();
		}
	}

}
